@@ -3,7 +3,8 @@
 
 mkdir tmp
 cd tmp
-wget -N http://git.savannah.gnu.org/cgit/config.git/plain/config.guess \
+wget --prefer-family=IPv4 -N \
+  http://git.savannah.gnu.org/cgit/config.git/plain/config.guess \
   http://git.savannah.gnu.org/cgit/config.git/plain/config.sub \
   http://git.savannah.gnu.org/cgit/automake.git/plain/lib/install-sh \
   http://git.savannah.gnu.org/cgit/automake.git/plain/lib/missing \
