@@ -33,7 +33,7 @@
    notice and this permission notice appear in supporting documentation.  This
    software is provided "as is" without express or implied warranty.
 
-   Derived "imagsize" program Copyright (C)2004-2024 by Brian Lindholm.  All
+   Derived "imagsize" program Copyright (C)2004-2025 by Brian Lindholm.  All
    rights reserved.  Redistribution is permitted as described as above.  */
 
 
@@ -57,6 +57,9 @@
 #ifdef HAVE_SYS_STAT_H
 # include <sys/stat.h>
 #endif
+#ifdef HAVE_FCNTL_H
+# include <fcntl.h>
+#endif
 
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
@@ -1012,6 +1015,9 @@ print_size (char *filename, int format, int verbose)
       perror (filename);
       return (NOT_OK);
     }
+#ifdef HAVE_POSIX_FADVISE
+  posix_fadvise(fileno(f), 0, 0, POSIX_FADV_RANDOM);
+#endif
   ok = image_size (f, &width, &height, qual, &depth, type, sampling);
   (void) fclose (f);
 
