@@ -15,7 +15,7 @@
  * This may be useful as an example of the minimum logic needed to parse
  * JPEG markers.
  *
- * Modifications Copyright (C) 2004-2021 by Brian Lindholm.  All rights
+ * Modifications Copyright (C) 2004-2025 by Brian Lindholm.  All rights
  * reserved except as specified above.
  */
 
@@ -35,6 +35,9 @@
 #ifdef HAVE_STRING_H
 # include <string.h>		/* other I/O functions */
 #endif
+#ifdef HAVE_FCNTL_H
+# include <fcntl.h>		/* to declare posix_fadvise() */
+#endif
 
 #ifdef HAVE_UNISTD_H
 # include <unistd.h>
@@ -344,6 +347,9 @@ print_com (char *filename, int raw)
   if ((infile = fopen(filename, "rb")) == NULL)
     fprintf(stderr, "jpgcom error: can't open %s\n", filename);
   else {
+#ifdef HAVE_POSIX_FADVISE
+    posix_fadvise(fileno(infile), 0, 0, POSIX_FADV_RANDOM);
+#endif
     fprintf(stdout, "%s", filename);
     scan_JPEG_header(raw);
     fprintf(stdout, "\n");
