@@ -13,15 +13,28 @@
    https://blake2.net.
 
    Modifications for portability and partial file reads by Brian Lindholm,
-   2020.
+   2020-2022.
 */
+
 #ifndef B2SUM_H
 #define B2SUM_H
 
-#if defined(__cplusplus)
-extern "C" {
+#ifdef __has_attribute
+# if (!defined __clang_minor__ || (defined __apple_build_version__ ? 6000000 <= __apple_build_version__ : 3 < __clang_major__ + (5 <= __clang_minor__)))
+#  define _GL_HAS_ATTRIBUTE(attr) __has_attribute (__##attr##__)
+# else
+#  define _GL_HAS_ATTRIBUTE(attr) _GL_ATTR_##attr
+# endif
+# if _GL_HAS_ATTRIBUTE (nonnull)
+#  define _GL_ATTRIBUTE_NONNULL(args) __attribute__ ((__nonnull__ args))
+# else
+#  define _GL_ATTRIBUTE_NONNULL(args)
+# endif
 #endif
 
-int blake2b_stream( FILE *stream, void *resstream, size_t outbytes, off_t readbytes );
+int blake2b_stream (FILE *stream, void *resstream, size_t outbytes, off_t readbytes)
+  _GL_ATTRIBUTE_NONNULL ((1));
+typedef int ( *blake2fn )( FILE *, void *, size_t );
+#define BLAKE2B_OUTBYTES 64
 
 #endif
