@@ -30,8 +30,7 @@ B2_256='n'
 B2_512='n'
 COUNT=''
 SKIP=''
-while getopts 12345678chn:o: opts
-do
+while getopts 12345678chn:o: opts ; do
   case $opts in
     1) MD5='y' ;;
     2) SHA1='y' ;;
