@@ -1,8 +1,8 @@
-/* tempname:  Creates a unique temporary file (or filename) for use by shell
-   scripts.
+/* tempname:  create a unique temporary file (or filename) for use by shell
+   scripts
 
-   Copyright (C) 2004-2021 by Brian Lindholm.
-   This file is part of the littleutils utility set.
+   Copyright (C) 2004-2025 by Brian Lindholm.  This file is part of the
+   littleutils utility set.
 
    The tempname utility is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as published by
