@@ -1,8 +1,8 @@
-/* rep_size:  Looks for duplicate files based on filesize.  Utilizes the output
-   of the filesize command.
+/* rep_size:  look for duplicate files based on filesize; utilizes the output
+   of the filesize command
 
-   Copyright (C) 2004-2021 by Brian Lindholm.
-   This file is part of the littleutils utility set.
+   Copyright (C) 2004-2025 by Brian Lindholm.  This file is part of the
+   littleutils utility set.
 
    The rep_size utility is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by the
